@@ -6,13 +6,11 @@ from .dicttoolz import *
 
 from .recipes import *
 
-from .compatibility import map, filter
-
-# from . import sandbox
-
 from functools import partial, reduce
 
 sorted = sorted
+map = map
+filter = filter
 
 # Aliases
 comp = compose
@@ -21,6 +19,8 @@ comp = compose
 flip = functoolz.flip = curry(functoolz.flip)
 memoize = functoolz.memoize = curry(functoolz.memoize)
 
+from . import curried  # sandbox
+
 functoolz._sigs.update_signature_registry()
 
 from ._version import __version__, __toolz_version__
